
# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

readme = ''

setup(
    long_description=readme,
    name='DrukBam',
    version='0.1.2.3',
    description='Comandline plotting of sort,indexed bam files',
    python_requires='==3.*,>=3.7.1',
    author='Stephan Holger Drukewitz',
    license='MIT',
    entry_points={"console_scripts": ["DrukBam = DrukBam.__main__:main"]},
    packages=['DrukBam'],
    package_dir={"": "."},
    package_data={"DrukBam": ["*.ini"]},
    install_requires=['cython==0.*,>=0.29.0', 'matplotlib==3.*,>=3.4.2', 'pandas==1.*,>=1.2.4', 'pysam==0.*,>=0.16.0', 'tqdm==4.*,>=4.61.1'],
)
